from .BinarySearch import binary_search
from .Bubble import bubble_sort
from .DFS import dfs
from .Heap import heap_sort
from .Insertion import insertion_sort
from .Merge import merge_sort
from .Quick import quick_sort
from .Selection import selection_sort
